@@ -1,7 +1,7 @@
 # coding: utf8
 # Debian Contributors data source data mining tools
 #
-# Copyright (C) 2013--2014  Enrico Zini <enrico@debian.org>
+# Copyright (C) 2013--2015  Enrico Zini <enrico@debian.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as
@@ -24,3 +24,5 @@ from .svn import *
 from .files import *
 from .postgres import *
 from .mailbox import *
+from .bts import *
+from .mock import *
